==> react-native-hotqa-sdk-0.1.1.tgz: package/src/pages/start/view/index.js <==
import React, {useState, useRef, useEffect} from 'react';
import {TouchableOpacity, View, Text, Image, Dimensions} from 'react-native';
import Swiper from '../../../components/swiper';
import Icon from 'react-native-vector-icons/Ionicons';
import {createSelector} from 'reselect';
import {useDispatch, useSelector} from 'react-redux';
import Slider from '@react-native-community/slider';

import SingleChoice from '../../../components/single-choice';
import MultipleChoice from '../../../components/multiple-choice';
import ImageChoice from '../../../components/image-choice';
import Writing from '../../../components/writing';
import AudioRecording from '../../../components/audio-recording';
import Reorder from '../../../components/reorder/index2';
import Matching from '../../../components/matching';
import FillInTheBlank from '../../../components/fill-in-the-blank';

import * as TYPE from '../../../common/constant';
import {onConfigurations} from '../../../common/helper';
import HTMLView from 'react-native-htmlview';
import {styles} from './style';
import ic_play from '../../../assets/images/ic_play.png';
import ic_pause from '../../../assets/images/ic_pause.png';
import song_nhac from '../../../assets/images/song_nhac.png';
import Sound from 'react-native-sound';
import {color_blue} from '../../../assets/colors';
import Player from '../../../components/player';

const width = Dimensions.get('screen').width;

Icon.loadFont();
const getData = createSelector(
  (state) => state.reducersAccepted,
  (reducersAccepted) => reducersAccepted,
);

const getKey = createSelector(
  (state) => state.reducerComponents,
  (reducerComponents) => reducerComponents,
);
const getUserAnswer = createSelector(
  (state) => state.submitData,
  (submitData) => submitData,
);
export default (props) => {
  const {navigation, route} = props;
  const dispatch = useDispatch();
  // const player = useRef(null);
  // const [sound, setSound] = useState(null);
  // const [isPlay, setIsPlay] = useState(true);
  const [isChoose, setChoose] = useState(false);
  // const [muted, setMute] = useState(false);
  const {data, loading, error} = useSelector(getData);
  const {user_answer} = useSelector(getUserAnswer);
  const {keyPage, isFinish} = useSelector(getKey);
  // const {test_data} = data;
  const {sections} = data;
  const sectionsData = sections.map((e, index) => {
    const section_id = e.id;
    const section_tag = e.tag;
    const questions = e.questions;
    const outline_s = e.outline;
    const extra = e.extra;
    const titleSection = e.title;
    const questionsData = questions.map((item) => {
      let configurations_type = '';
      const configurations = JSON.parse(item.configurations);
      if (Array.isArray(configurations) && configurations.length > 0) {
        configurations_type = configurations[0].data.type;
      }
      if (item.extra && JSON.parse(item.extra).length > 0) {
        return {
          ...item,
          section_id,
          section_tag,
          outline_s,
          configurations_type,
          titleSection,
        };
      }
      return {
        ...item,
        section_id,
        section_tag,
        outline_s,
        extra,
        configurations_type,
        titleSection,
      };
    });
    return questionsData;
  });

  let limitMedia = 5;
  if (data.extra) {
    const parseExtra = JSON.parse(data.extra);
    if (parseExtra.media) {
      limitMedia = parseExtra.media.limit_play;
    }
  }
  const [limitPlay, setLimitPlay] = useState(limitMedia);
  // console.log(63, test_data.extra);

  const questions = sectionsData.flat();
  let sound = null;

  const onPauseAudio = (type) => {
    if (sound) {
      if (type === 'Record') {
        sound.stop();
      }
    }
  };

  Sound.setCategory('Playback', false);
  const playAudio = (item, index) => {
    if (keyPage === index && limitPlay > 0) {
      if (!sound) {
        sound = new Sound(item.value, null, (error) => {
          if (error) {
            return;
          }
          if (!isChoose) {
            sound.play(() => setLimitPlay(limitPlay - 1));
          }
        });
      }
    }
  };

  const stopAudio = () => {
    if (sound) {
      sound.stop();
    }
  };

  const viewTitle = (item, i) => {
    switch (item.type) {
      case 'image':
        return <Image source={{uri: item.value}} style={styles.imgQuestion} />;
      case 'text':
        return <Text style={styles.outline}>{item.value}</Text>;

      case 'audio':
        playAudio(item, i);
        return (
          // <Player
          //   keyPage={keyPage}
          //   item={item}
          //   index={i}
          //   sound={sound}
          //   ref={player}
          // />
          <View style={styles.viewPlayer}>
            <TouchableOpacity
              onPress={() => {
                if (sound) {
                  // setChoose(false);
                  sound.play(() => setLimitPlay(limitPlay - 1));
                }
              }}>
              <Image source={ic_play} style={styles.iconPlayPause} />
            </TouchableOpacity>
            <Image
              source={song_nhac}
              style={{flex: 1, height: 50, opacity: 0.3}}
            />
          </View>
        );
    }
  };

  return (
    <View>
      <Swiper
        questions={questions}
        navigation={navigation}
        stopSound={() => {
          setChoose(false);
          setLimitPlay(limitMedia);
          stopAudio();
        }}
        keyPage={keyPage}
        route={route.params?.nav}>
        {questions.map((item, i) => {
          const extra =
            JSON.parse(item.extra) === null ? [] : JSON.parse(item.extra);
          const configurations = JSON.parse(item.configurations);

          const type = item.type;
          const {outline, outline_s} = item;
          // console.log(166, i, item);
          return (
            <View style={[styles.slide]} key={i}>
              {(outline_s ||
                outline ||
                (extra !== null && extra.length > 0)) && (
                <View style={styles.viewOutline}>
                  {outline_s ? (
                    <HTMLView
                      value={outline_s}
                      style={{marginHorizontal: 20}}
                    />
                  ) : null}
                  {outline ? (
                    <HTMLView value={outline} style={{marginHorizontal: 20}} />
                  ) : null}
                  {extra.length > 0 && (
                    <View style={styles.viewTitle}>
                      {/* {viewTitle(extra)} */}
                      {extra[0] && viewTitle(extra[0], i)}
                      {extra[1] && viewTitle(extra[1], i)}
                    </View>
                  )}
                </View>
              )}
              <View style={{flex: 0.6}}>
                <Text style={styles.title}>{item.title}</Text>
                <View style={{marginTop: 10}}>
                  {type === TYPE.SINGLE_CHOICE &&
                    item.configurations_type !== 'image' && (
                      <SingleChoice
                        data={configurations}
                        item_question={item}
                        user_answer={user_answer}
                        onPress={(items) => {
                          setChoose(true);
                          stopAudio();
                          onConfigurations(
                            {...item, items},
                            user_answer,
                            dispatch,
                          );
                        }}
                        keyPage={keyPage}
                        index={i}
                        isFinish={isFinish}
                      />
                    )}

                  {type === TYPE.MULTIPLE_CHOICE &&
                    item.configurations_type !== 'image' && (
                      <MultipleChoice
                        onPress={(items) => {
                          setChoose(true);
                          stopAudio();
                          onConfigurations(
                            {...item, items},
                            user_answer,
                            dispatch,
                          );
                        }}
                        data={configurations}
                        item_question={item}
                        user_answer={user_answer}
                        keyPage={keyPage}
                        index={i}
                        isFinish={isFinish}
                      />
                    )}

                  {item.configurations_type === 'image' && (
                    <ImageChoice
                      data={configurations}
                      type={type}
                      dispatch={dispatch}
                      user_answer={user_answer}
                      item_question={item}
                      keyPage={keyPage}
                      index={i}
                      isFinish={isFinish}
                      audio={() => {
                        setChoose(true);
                        stopAudio();
                      }}
                    />
                  )}
                  {type === TYPE.WRITING && (
                    <Writing
                      item={item}
                      dispatch={dispatch}
                      isFinish={isFinish}
                    />
                  )}
                  {type === TYPE.REORDER && (
                    <Reorder
                      item={item}
                      dispatch={dispatch}
                      isFinish={isFinish}
                    />
                  )}
                  {type === TYPE.MATCHING && (
                    <Matching
                      item={item}
                      dispatch={dispatch}
                      pSound={(res) => (sound = res)}
                      isFinish={isFinish}
                    />
                  )}
                  {type === TYPE.FILL_IN_THE_BLANK && (
                    <FillInTheBlank
                      item={item}
                      dispatch={dispatch}
                      isFinish={isFinish}
                    />
                  )}
                  {type === TYPE.AUDIO_RECORDING && (
                    <AudioRecording
                      item={item}
                      onPauseAudio={(type) => onPauseAudio(type)}
                      isFinish={isFinish}
                    />
                  )}
                </View>
              </View>
            </View>
          );
        })}
      </Swiper>
    </View>
  );
};

==> react-native-hotqa-sdk-0.1.6.tgz: package/src/pages/start/view/index.js <==
import React, {useState, useRef, useEffect} from 'react';
import {TouchableOpacity, View, Text, Image, Dimensions} from 'react-native';
import Swiper from '../../../components/swiper';
import Icon from 'react-native-vector-icons/Ionicons';
import {createSelector} from 'reselect';
import {useDispatch, useSelector} from 'react-redux';
import Slider from '@react-native-community/slider';

import SingleChoice from '../../../components/single-choice';
import MultipleChoice from '../../../components/multiple-choice';
import ImageChoice from '../../../components/image-choice';
import Writing from '../../../components/writing';
import AudioRecording from '../../../components/audio-recording';
import Reorder from '../../../components/reorder/index2';
import Matching from '../../../components/matching';
import FillInTheBlank from '../../../components/fill-in-the-blank';

import * as TYPE from '../../../common/constant';
import {onConfigurations} from '../../../common/helper';
import HTMLView from 'react-native-htmlview';
import {styles} from './style';
import ic_play from '../../../assets/images/ic_play.png';
import ic_pause from '../../../assets/images/ic_pause.png';
import song_nhac from '../../../assets/images/song_nhac.png';
import Sound from 'react-native-sound';
import {color_blue} from '../../../assets/colors';
import Player from '../../../components/player';

const width = Dimensions.get('screen').width;

Icon.loadFont();
const getData = createSelector(
  (state) => state.reducersAccepted,
  (reducersAccepted) => reducersAccepted,
);

const getKey = createSelector(
  (state) => state.reducerComponents,
  (reducerComponents) => reducerComponents,
);
const getUserAnswer = createSelector(
  (state) => state.submitData,
  (submitData) => submitData,
);
export default (props) => {
  const {navigation, route} = props;
  const dispatch = useDispatch();
  // const player = useRef(null);
  // const [sound, setSound] = useState(null);
  // const [isPlay, setIsPlay] = useState(true);
  const [isChoose, setChoose] = useState(false);
  // const [muted, setMute] = useState(false);
  const {data, loading, error} = useSelector(getData);
  const {user_answer} = useSelector(getUserAnswer);
  const {keyPage, isFinish} = useSelector(getKey);
  // const {test_data} = data;
  const {sections} = data;
  const sectionsData = sections.map((e, index) => {
    const section_id = e.id;
    const section_tag = e.tag;
    const questions = e.questions;
    const outline_s = e.outline;
    const extra = e.extra;
    const titleSection = e.title;
    const questionsData = questions.map((item) => {
      let configurations_type = '';
      const configurations = JSON.parse(item.configurations);
      if (Array.isArray(configurations) && configurations.length > 0) {
        configurations_type = configurations[0].data.type;
      }
      if (item.extra && JSON.parse(item.extra).length > 0) {
        return {
          ...item,
          section_id,
          section_tag,
          outline_s,
          configurations_type,
          titleSection,
        };
      }
      return {
        ...item,
        section_id,
        section_tag,
        outline_s,
        extra,
        configurations_type,
        titleSection,
      };
    });
    return questionsData;
  });

  let limitMedia = 3;
  if (data.extra) {
    const parseExtra = JSON.parse(data.extra);
    if (parseExtra.media) {
      const {limit_play} = parseExtra.media;
      if (limit_play > 0) {
        limitMedia = limit_play;
      }
    }
  }
  const [limitPlay, setLimitPlay] = useState(limitMedia);
  // console.log(63, test_data.extra);

  const questions = sectionsData.flat();
  let sound = null;

  const onPauseAudio = (type) => {
    if (sound) {
      if (type === 'Record') {
        sound.stop();
      }
    }
  };

  Sound.setCategory('Playback', false);
  const playAudio = (item, index) => {
    if (keyPage === index && limitPlay > 0) {
      if (!sound) {
        sound = new Sound(item.value, null, (error) => {
          if (error) {
            return;
          }
          if (!isChoose) {
            sound.play(() => setLimitPlay(limitPlay - 1));
          }
        });
      }
    }
  };

  const stopAudio = () => {
    if (sound) {
      sound.stop();
    }
  };

  const viewTitle = (item, i) => {
    switch (item.type) {
      case 'image':
        return <Image source={{uri: item.value}} style={styles.imgQuestion} />;
      case 'text':
        // return <Text style={styles.outline}>{item.value}</Text>;
        return <HTMLView value={item.value} style={{marginBottom: 10}} />;
      case 'audio':
        playAudio(item, i);
        return (
          // <Player
          //   keyPage={keyPage}
          //   item={item}
          //   index={i}
          //   sound={sound}
          //   ref={player}
          // />
          <View style={styles.viewPlayer}>
            <TouchableOpacity
              onPress={() => {
                if (sound) {
                  // setChoose(false);
                  sound.play(() => setLimitPlay(limitPlay - 1));
                }
              }}>
              <Image source={ic_play} style={styles.iconPlayPause} />
            </TouchableOpacity>
            <Image
              source={song_nhac}
              style={{flex: 1, height: 50, opacity: 0.3}}
            />
          </View>
        );
    }
  };

  return (
    <View>
      <Swiper
        questions={questions}
        navigation={navigation}
        stopSound={() => {
          setChoose(false);
          setLimitPlay(limitMedia);
          stopAudio();
        }}
        keyPage={keyPage}
        route={route.params?.nav}>
        {questions.map((item, i) => {
          const extra =
            JSON.parse(item.extra) === null ? [] : JSON.parse(item.extra);
          const configurations = JSON.parse(item.configurations);

          const type = item.type;
          const {outline, outline_s} = item;
          // console.log(166, i, item);
          return (
            <View style={[styles.slide]} key={i}>
              {(outline_s ||
                outline ||
                (extra !== null && extra.length > 0)) && (
                <View style={styles.viewOutline}>
                  {outline_s ? (
                    <HTMLView
                      value={outline_s}
                      style={{marginHorizontal: 20}}
                    />
                  ) : null}
                  {outline ? (
                    <HTMLView value={outline} style={{marginHorizontal: 20}} />
                  ) : null}
                  {extra.length > 0 && (
                    <View style={styles.viewTitle}>
                      {/* {viewTitle(extra)} */}
                      {extra[0] && viewTitle(extra[0], i)}
                      {extra[1] && viewTitle(extra[1], i)}
                    </View>
                  )}
                </View>
              )}
              <View style={{flex: 0.6}}>
                <Text style={styles.title}>{item.title}</Text>
                <View style={{marginTop: 10}}>
                  {type === TYPE.SINGLE_CHOICE &&
                    item.configurations_type !== 'image' && (
                      <SingleChoice
                        data={configurations}
                        item_question={item}
                        user_answer={user_answer}
                        onPress={(items) => {
                          setChoose(true);
                          stopAudio();
                          onConfigurations(
                            {...item, items},
                            user_answer,
                            dispatch,
                          );
                        }}
                        keyPage={keyPage}
                        index={i}
                        isFinish={isFinish}
                      />
                    )}

                  {type === TYPE.MULTIPLE_CHOICE &&
                    item.configurations_type !== 'image' && (
                      <MultipleChoice
                        onPress={(items) => {
                          setChoose(true);
                          stopAudio();
                          onConfigurations(
                            {...item, items},
                            user_answer,
                            dispatch,
                          );
                        }}
                        data={configurations}
                        item_question={item}
                        user_answer={user_answer}
                        keyPage={keyPage}
                        index={i}
                        isFinish={isFinish}
                      />
                    )}

                  {item.configurations_type === 'image' && (
                    <ImageChoice
                      data={configurations}
                      type={type}
                      dispatch={dispatch}
                      user_answer={user_answer}
                      item_question={item}
                      keyPage={keyPage}
                      index={i}
                      isFinish={isFinish}
                      audio={() => {
                        setChoose(true);
                        stopAudio();
                      }}
                    />
                  )}
                  {type === TYPE.WRITING && (
                    <Writing
                      item={item}
                      dispatch={dispatch}
                      isFinish={isFinish}
                      audio={() => {
                        stopAudio();
                      }}
                    />
                  )}
                  {type === TYPE.REORDER && (
                    <Reorder
                      item={item}
                      dispatch={dispatch}
                      isFinish={isFinish}
                    />
                  )}
                  {type === TYPE.MATCHING && (
                    <Matching
                      item={item}
                      dispatch={dispatch}
                      pSound={(res) => (sound = res)}
                      isFinish={isFinish}
                    />
                  )}
                  {type === TYPE.FILL_IN_THE_BLANK && (
                    <FillInTheBlank
                      item={item}
                      dispatch={dispatch}
                      isFinish={isFinish}
                      audio={() => {
                        stopAudio();
                      }}
                    />
                  )}
                  {type === TYPE.AUDIO_RECORDING && (
                    <AudioRecording
                      item={item}
                      onPauseAudio={() => {
                        setChoose(true);
                        stopAudio();
                      }}
                      isFinish={isFinish}
                    />
                  )}
                </View>
              </View>
            </View>
          );
        })}
      </Swiper>
    </View>
  );
};
